==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="br">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>An holl skriturioù</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Implijader</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Oberiant</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Sinaeg</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Etrelinenn simpl</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Dilemel</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Enaouiñ</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Lazhañ</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Restr torret</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Memes stumm staliet</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Skritur ar sistem</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ktrl+Pennlizh+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PjUs</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PjTraoñ</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ktrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ktrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ktrlo+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ktrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ktrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ktrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 skritur staliet</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 skritur staliet</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">Restr torret</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ne vo ket hegerz ken ar skritur-mañ evit an aplikasionoù</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ne vo ket hegerz ken ar skriturioù-mañ evit an aplikasionoù</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Dilemel</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>O tilemel ar skriturioù, gortozit mar plij...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Gwiriañ ar skriturioù</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Skritur ebet da staliañ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">Kuitaat</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Kenderc&apos;hel</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Titour diazez</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Doare</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Stumm</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Deskrivadur</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Dizanv</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Anv</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps anv</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Merkoù marilhet</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Merer skriturioù</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Ar merer skriturioù a sikour an implijaderien da staliañ ha da verañ ar skriturioù.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>O kargañ ar skriturioù, gortozit mar plij...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Ar skritur a zo bet ezporzhiet d&apos;ho purev</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 skritur ezporzhiet d&apos;ho purev</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>N&apos;heller ket ezporzhiañ 1 skritur. N&apos;eus ket plas ebet ken en disk.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>N&apos;heller ket ezporzhiañ %1 skritur. N&apos;eus ket plas ebet ken en disk.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Ouzhpennañ ar skritur</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Enaouiñ</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Lazhañ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Disinedet</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Munudoù</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Diskouez ar merer restroù</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ezporzhiañ</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>lazhet</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Lazhet eo bet ar skriturioù</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 a zo war implij, setu ma n&apos;hallit ket lazhañ anezhañ</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>N&apos;heller ket lazhañ skriturioù ar sistem hag ar re war implij kenebeut</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>N&apos;heller ket lazhañ skriturioù ar sistem</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Staliañ ar skritur</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>O wiriañ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Dizanv</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Restr torret</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Staliet</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nann-staliet</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Staliañ ar skritur</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Klask</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Disoc&apos;h ebet kavet</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Skritur ebet</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Skoazell</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Diskouez ar berradurioù</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pajenn gent</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pajenn da-heul</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Ouzhpennañ ar skritur</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Disinedet</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Titouroù ar skritur</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Ebarzhit un destenn rakwelet</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_br.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="br">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>An holl skriturioù</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Implijader</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>Oberiant</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Sinaeg</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>Etrelinenn simpl</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Dilemel</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Enaouiñ</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Lazhañ</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Nullañ</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>Restr torret</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>Memes stumm staliet</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>Skritur ar sistem</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ktrl+Pennlizh+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PjUs</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PjTraoñ</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ktrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ktrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ktrlo+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ktrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ktrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ktrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 skritur staliet</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 skritur staliet</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Skriturioù</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>Restr torret</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>Ne vo ket hegerz ken ar skritur-mañ evit an aplikasionoù</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>Ne vo ket hegerz ken ar skriturioù-mañ evit an aplikasionoù</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Dilemel</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>O tilemel ar skriturioù, gortozit mar plij...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>Gwiriañ ar skriturioù</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>Skritur ebet da staliañ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kuitaat</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Kenderc&apos;hel</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Na lezit ket hoc&apos;h hunvreoù bezañ hunvreoù</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>Titour diazez</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Stil</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Doare</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Stumm</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Deskrivadur</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Dizanv</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>Anv</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps anv</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>Merkoù marilhet</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>Merer skriturioù</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Ar merer skriturioù a sikour an implijaderien da staliañ ha da verañ ar skriturioù.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>O kargañ ar skriturioù, gortozit mar plij...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>Ar skritur a zo bet ezporzhiet d&apos;ho purev</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 skritur ezporzhiet d&apos;ho purev</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>N&apos;heller ket ezporzhiañ 1 skritur. N&apos;eus ket plas ebet ken en disk.</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>N&apos;heller ket ezporzhiañ %1 skritur. N&apos;eus ket plas ebet ken en disk.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>Ouzhpennañ ar skritur</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Enaouiñ</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Lazhañ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Disinedet</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Munudoù</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Diskouez ar merer restroù</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ezporzhiañ</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>lazhet</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>Lazhet eo bet ar skriturioù</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 a zo war implij, setu ma n&apos;hallit ket lazhañ anezhañ</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>N&apos;heller ket lazhañ skriturioù ar sistem hag ar re war implij kenebeut</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>N&apos;heller ket lazhañ skriturioù ar sistem</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>Staliañ ar skritur</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>O wiriañ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>Dizanv</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>Restr torret</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>Staliet</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>Nann-staliet</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>Staliañ ar skritur</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>Klask</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Disoc&apos;h ebet kavet</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>Skritur ebet</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>Skoazell</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Diskouez ar berradurioù</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Pajenn gent</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Pajenn da-heul</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dilemel</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Ouzhpennañ ar skritur</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Sinedoù</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Disinedet</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>Titouroù ar skritur</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>Ebarzhit un destenn rakwelet</translation>
    </message>
</context>
</TS>
